@@ -16,7 +16,7 @@ from .emission import validate_linked_terms
 from .input import validate_must_include_id, validate_input_country, validate_related_impacts
 from .practice import (
     validate_cropResidueManagement, validate_longFallowPeriod, validate_excretaManagement, validate_no_tillage,
-    validate_tillage_site_type, validate_tillage_values
+    validate_tillage_site_type, validate_tillage_values, validate_liveAnimal_system
 )
 from .product import (
     validate_economicValueShare, validate_value_empty, validate_value_0, validate_excreta,
@@ -25,10 +25,11 @@ from .product import (
 from .data_completeness import validate_dataCompleteness
 from .transformation import (
     validate_previous_transformation, validate_first_transformation_fields, validate_transformation_excretaManagement,
-    validate_first_transformation_input
+    validate_first_transformation_input, validate_linked_emission
 )
 from .property import (
-    validate_valueType as validate_properties_valueType, validate_default_value as validate_properties_default_value
+    validate_valueType as validate_properties_valueType, validate_default_value as validate_properties_default_value,
+    validate_volatileSolidsContent
 )
 
 
@@ -102,9 +103,10 @@ def _crop_residue_terms():
 
 
 def validate_crop_residue_completeness(cycle: dict, site: dict):
+    terms = _crop_residue_terms()
+
     def validate_sum():
         products = cycle.get('products', [])
-        terms = _crop_residue_terms()
         sum_above_ground = _list_sum_terms(products, list(filter(lambda term: term.startswith('above'), terms)))
         sum_below_ground = _list_sum_terms(products, list(filter(lambda term: term.startswith('below'), terms)))
         return all([sum_above_ground > 0, sum_below_ground > 0]) or {
@@ -207,7 +209,7 @@ def validate_cycle(cycle: dict, node_map: dict = {}):
         validate_properties_default_value(cycle, 'emissions'),
         validate_properties_valueType(cycle, 'emissions'),
         validate_linked_terms(cycle, 'emissions', 'inputs', 'inputs', True),
-        validate_linked_terms(cycle, 'emissions', 'transformation', 'transformations', True),
+        validate_linked_terms(cycle, 'emissions', 'transformation', 'transformations', True)
     ] if len(cycle.get('emissions', [])) > 0 else []) + flatten([
         validate_list_dates(cycle, 'inputs'),
         validate_list_dates_format(cycle, 'inputs'),
@@ -218,6 +220,7 @@ def validate_cycle(cycle: dict, node_map: dict = {}):
         validate_list_term_percent(cycle, 'inputs'),
         validate_properties_default_value(cycle, 'inputs'),
         validate_properties_valueType(cycle, 'inputs'),
+        validate_volatileSolidsContent(cycle, 'inputs'),
         validate_must_include_id(cycle['inputs']),
         validate_input_country(cycle, 'inputs'),
         validate_related_impacts(cycle, 'inputs', node_map)
@@ -236,6 +239,7 @@ def validate_cycle(cycle: dict, node_map: dict = {}):
         validate_product_primary(cycle.get('products')),
         validate_properties_default_value(cycle, 'products'),
         validate_properties_valueType(cycle, 'products'),
+        validate_volatileSolidsContent(cycle, 'products'),
         validate_crop_residue_completeness(cycle, site) if 'dataCompleteness' in cycle and site else True,
         validate_list_model_config(cycle, 'products', PRODUCTS_MODEL_CONFIG),
         validate_excreta(cycle, 'products')
@@ -254,7 +258,8 @@ def validate_cycle(cycle: dict, node_map: dict = {}):
         validate_excretaManagement(cycle, cycle.get('practices')),
         validate_no_tillage(cycle.get('practices')),
         validate_tillage_site_type(cycle.get('practices'), site) if site else True,
-        validate_tillage_values(cycle.get('practices'))
+        validate_tillage_values(cycle.get('practices')),
+        validate_liveAnimal_system(cycle)
     ] if len(cycle.get('practices', [])) > 0 else []) + flatten([
         validate_functionalUnit(cycle, site)
     ] if 'functionalUnit' in cycle and site else []) + flatten([
@@ -264,5 +269,6 @@ def validate_cycle(cycle: dict, node_map: dict = {}):
         validate_previous_transformation(cycle.get('transformations')),
         validate_first_transformation_fields(cycle.get('transformations')),
         validate_first_transformation_input(cycle, cycle.get('transformations')),
-        validate_transformation_excretaManagement(cycle.get('transformations'))
-    ] if len(cycle.get('transformations', [])) > 0 in cycle else [])
+        validate_transformation_excretaManagement(cycle.get('transformations')),
+        validate_linked_emission(cycle, 'transformations')
+    ] if len(cycle.get('transformations', [])) > 0 else [])
