@@ -1,6 +1,6 @@
 from hestia_earth.schema import TermTermType
 from hestia_earth.utils.model import find_primary_product
-from hestia_earth.utils.lookup import get_table_value, download_lookup
+from hestia_earth.utils.lookup import get_table_value, download_lookup, column_name
 from hestia_earth.utils.tools import list_sum, flatten
 
 from hestia_earth.validation.utils import _list_sum, _filter_list_errors
@@ -77,7 +77,7 @@ def _get_excreta_term(cycle: dict):
     term_id = product.get('term', {}).get('@id')
     term_type = product.get('term', {}).get('termType')
     lookup = download_lookup(f"{term_type}.csv")
-    return product, get_table_value(lookup, 'termid', term_id, 'excreta')
+    return product, get_table_value(lookup, 'termid', term_id, column_name('excretaKgNTermId'))
 
 
 def validate_excreta(cycle: dict, list_key: str = 'products'):
