@@ -3,7 +3,7 @@ from hestia_earth.utils.lookup import column_name, download_lookup, get_table_va
 from hestia_earth.utils.model import find_term_match
 from hestia_earth.utils.tools import flatten, non_empty_list, safe_parse_float
 
-from .shared import update_error_path, _filter_list_errors, value_difference
+from .shared import update_error_path, _filter_list_errors, value_difference, _is_value_below
 
 
 PROPERTIES_KEY = 'properties'
@@ -81,9 +81,57 @@ def validate_default_value(node: dict, list_key: str):
         return validate
 
     def validate(values: tuple):
-        index, value = values
-        term_id = value.get('term', {}).get('@id')
-        errors = list(map(is_valid(term_id), enumerate(value.get(PROPERTIES_KEY, []))))
+        index, blank_node = values
+        term_id = blank_node.get('term', {}).get('@id')
+        errors = list(map(is_valid(term_id), enumerate(blank_node.get(PROPERTIES_KEY, []))))
+        return _filter_list_errors(
+            [update_error_path(error, list_key, index) for error in errors if error is not True]
+        )
+
+    return _filter_list_errors(flatten(map(validate, enumerate(node.get(list_key, [])))))
+
+
+VSC_ID = 'volatileSolidsContent'
+VSC_MIN = {
+    'kg': 0,
+    'kg Vs': 100,
+    'kg N': 0
+}
+VSC_MAX = {
+    'kg': 100,
+    'kg Vs': 100,
+    'kg N': None
+}
+
+
+def _volatileSolidsContent_error(min: float = None, max: float = None):
+    return f"must be {max}" if min == max else (
+        f"must be above {min}" if max is None else (
+            f"must be below {max}" if min is None else f"must be between {min} and {max}"
+        )
+    )
+
+
+def validate_volatileSolidsContent(node: dict, list_key: str):
+    def is_valid(blank_node: dict):
+        units = blank_node.get('term', {}).get('units')
+
+        def validate(values: tuple):
+            index, property = values
+            term_id = property.get('term', {}).get('@id')
+            value = property.get('value', 0)
+            min = VSC_MIN.get(units)
+            max = VSC_MAX.get(units)
+            return term_id != VSC_ID or all([_is_value_below(value, max), _is_value_below(min, value)]) or {
+                'level': 'error',
+                'dataPath': f".{PROPERTIES_KEY}[{index}].value",
+                'message': _volatileSolidsContent_error(min, max)
+            }
+        return validate
+
+    def validate(values: tuple):
+        index, blank_node = values
+        errors = flatten(map(is_valid(blank_node), enumerate(blank_node.get(PROPERTIES_KEY, []))))
         return _filter_list_errors(
             [update_error_path(error, list_key, index) for error in errors if error is not True]
         )
