@@ -11,7 +11,7 @@ from hestia_earth.validation.geojson import get_geojson_area
 from hestia_earth.validation.gee import is_enabled, id_to_level, get_region_id, get_region_size, get_boundary_size
 from hestia_earth.validation.utils import (
     update_error_path, _filter_list_errors, _next_error, _value_average,
-    _find_linked_node, _is_before_today, run_model_from_node, run_model, _get_dict_key,
+    _find_linked_node, _is_before_today, run_model_from_node, run_model, _value_from_model, _get_dict_key,
     _list_except_item, _dict_without_key, _hash_dict, _value_range_error
 )
 
@@ -446,28 +446,6 @@ def is_value_different(value: float, expected_value: float, delta: float = 0.05)
     return value_difference(value, expected_value) > delta
 
 
-def _model_value_from_list(results: list, default_value: float):
-    return results[0].get('value', [default_value]) if len(results) > 0 else default_value
-
-
-def _model_value(result, default_value=0):
-    return default_value if result is None else (
-        _model_value_from_list(result, default_value) if isinstance(result, list) else (
-            result.get('value', [default_value]) if isinstance(result, dict) else default_value
-        )
-    )
-
-
-def _value_from_model(result):
-    value = _model_value(result)
-    try:
-        # fix numpy.float64
-        # TODO: find a better way to handle this
-        return list_sum(value, float(value))
-    except Exception:
-        return list_sum(value, value)
-
-
 def _parse_node_value(node: dict):
     def parse_list_value(value: list):
         return list_sum(value) if len(value) > 0 else None
