@@ -203,7 +203,7 @@ def test_validate_require_startDate_endDate_invalid():
     }]
 
 
-@patch(f"{class_path}.fetch_data", return_value={'mean': 1})
+@patch("hestia_earth.models.spatial.rainfallAnnual._run", return_value={'value': [1000]})
 def test_validate_with_models_valid(*args):
     # no measurements should be valid
     assert validate_with_models({}, 'measurements') is True
@@ -213,7 +213,7 @@ def test_validate_with_models_valid(*args):
     assert validate_with_models(data, 'measurements') is True
 
 
-@patch(f"{class_path}.fetch_data", return_value={'mean': 1})
+@patch("hestia_earth.models.spatial.rainfallAnnual._run", return_value={'value': [1000]})
 def test_validate_with_models_warning(*args):
     with open(f"{fixtures_path}/measurement/models/warning.json") as f:
         data = json.load(f)
@@ -230,7 +230,8 @@ def test_validate_with_models_warning(*args):
                 '@id': 'rainfallAnnual',
                 '@type': 'Term',
                 'name': 'Rainfall annual'
-            }
+            },
+            'model': {}
         }
     }
 
@@ -250,7 +251,8 @@ def test_validate_with_models_warning(*args):
                 '@id': 'rainfallAnnual',
                 '@type': 'Term',
                 'name': 'Rainfall annual'
-            }
+            },
+            'model': {}
         }
     }
 
