@@ -9,7 +9,8 @@ from hestia_earth.validation.validators.practice import (
     validate_excretaManagement,
     validate_no_tillage,
     validate_tillage_site_type,
-    validate_tillage_values
+    validate_tillage_values,
+    validate_liveAnimal_system
 )
 
 
@@ -174,3 +175,22 @@ def test_validate_tillage_values_invalid():
             ]
         }
     }
+
+
+def test_validate_liveAnimal_system_valid():
+    # no practices should be valid
+    assert validate_liveAnimal_system({}) is True
+
+    with open(f"{fixtures_path}/practice/liveAnimal-system/valid.json") as f:
+        data = json.load(f)
+    assert validate_liveAnimal_system(data) is True
+
+
+def test_validate_liveAnimal_system_invalid():
+    with open(f"{fixtures_path}/practice/liveAnimal-system/invalid.json") as f:
+        data = json.load(f)
+    assert validate_liveAnimal_system(data) == {
+        'level': 'warning',
+        'dataPath': '.practices',
+        'message': 'should add an animal production system'
+    }
